package com.onsiteservice.miniapp.controller.order;

import com.onsiteservice.common.annotation.user.CurrentUserId;
import com.onsiteservice.core.result.Result;
import com.onsiteservice.dao.common.page.PageInfoVO;
import com.onsiteservice.entity.order.ServiceOrder;
import com.onsiteservice.miniapp.controller.order.dto.PageServiceOrderDTO;
import com.onsiteservice.miniapp.controller.order.dto.SaveServiceOrderDTO;
import com.onsiteservice.miniapp.controller.order.dto.ValuationServiceOrderDTO;
import com.onsiteservice.miniapp.controller.order.vo.ServiceOrderVO;
import com.onsiteservice.miniapp.service.order.ServiceOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.NonNull;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.annotation.Resource;
import javax.validation.constraints.Positive;

import java.util.List;

import static com.onsiteservice.core.result.ResultGenerator.fail;
import static com.onsiteservice.core.result.ResultGenerator.success;

/**
 * <P>订单模块</P>
 *
 * @author 李宁
 * @version v1.0
 * @since 2022/7/7 08:51
 */
@Api(tags = "订单模块")
@RestController
@RequestMapping("/order/")
@Validated
public class ServiceOrderController {


    @Resource
    private ServiceOrderService serviceOrderService;


    @ApiOperation(value = "根据id查询订单详情")
    @GetMapping("get/{id}")
    public Result<ServiceOrderVO> getDetail(@ApiParam(name = "id", value = "订单id") @PathVariable @Positive Long id, @CurrentUserId Long userId) {
        return success(serviceOrderService.selectById(id, userId), "根据id查询订单详情");
    }

    @ApiOperation(value = "分页查询订单")
    @PostMapping("page")
    public Result<PageInfoVO<ServiceOrderVO>> getPage(@RequestBody @NonNull @Validated PageServiceOrderDTO dto, @CurrentUserId Long userId) {
        return serviceOrderService.selectByUserId(dto, userId);
    }

    @ApiOperation(value = "订单预约")
    @PostMapping("reserve")
    public Result save(@RequestBody @NonNull @Validated SaveServiceOrderDTO dto, @CurrentUserId Long userId) {
        return serviceOrderService.save(dto, userId) == 1 ? success() : fail("已预约");
    }

    @ApiOperation(value = "订单估计")
    @PutMapping("valuation")
    public Result valuation(@RequestBody @NonNull @Validated ValuationServiceOrderDTO dto) {
        return serviceOrderService.valuation(dto) == 1 ? success() : fail("估价失败");
    }


}
